@@ -36,15 +36,15 @@ import urllib.parse
 import warnings
 from functools import partialmethod
 from logging import error, info, warning
-from typing import Generator, List, Optional, Text, Tuple, Set
-
-import requests
+from typing import Generator, List, Optional, Set, Text, Tuple
 
 import act.api
+import requests
 from act.api.libs import cli
-from act.workers.libs import worker
 from virus_total_apis import PublicApi as VirusTotalApi
 
+from act.workers.libs import worker
+
 ADWARE_OVERRIDES = ["opencandy", "monetize", "adload", "somoto"]
 
 HASH_RE = re.compile(r"^([0-9a-f]{32}|[0-9a-f]{40}|[0-9a-f]{64}|[0-9a-f]{128})$")
